<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=sv
// ** ne pas modifier le fichier **

return [

	// D
	'diff_para_ajoute' => 'Tillaggt stycke',
	'diff_para_deplace' => 'Flyttat stycke',
	'diff_para_supprime' => 'Raderat stycke',
	'diff_texte_ajoute' => 'Tillaggd text',
	'diff_texte_deplace' => 'Flyttad text',
	'diff_texte_supprime' => 'Raderad text',

	// I
	'info_historique' => 'Versioner:',
	'info_historique_lien' => 'Visa versioner',
	'info_historique_titre' => 'Versionshantering',

	// V
	'version_initiale' => 'Utgångsversion',
];
